@@ -132,23 +132,36 @@ void __fastcall TPreferencesF::General_Output_SelChange(TObject *Sender)
     }
     if (General_Output_Sel->ItemIndex==6)
     {
-        Prefs->Config(__T("Output"))=__T("MPEG-7");
+        Prefs->Config(__T("Output"))=__T("JSON");
         MainF->Page->ActivePage=MainF->Page_Custom;
         General_Output_More->Visible=false;
     }
+
     if (General_Output_Sel->ItemIndex==7)
     {
-        Prefs->Config(__T("Output"))=__T("PBCore_1.2");
+        Prefs->Config(__T("Output"))=__T("MPEG-7");
         MainF->Page->ActivePage=MainF->Page_Custom;
         General_Output_More->Visible=false;
     }
     if (General_Output_Sel->ItemIndex==8)
     {
-        Prefs->Config(__T("Output"))=__T("reVTMD");
+        Prefs->Config(__T("Output"))=__T("PBCore_1.2");
         MainF->Page->ActivePage=MainF->Page_Custom;
         General_Output_More->Visible=false;
     }
     if (General_Output_Sel->ItemIndex==9)
+    {
+        Prefs->Config(__T("Output"))=__T("PBCore_2.0");
+        MainF->Page->ActivePage=MainF->Page_Custom;
+        General_Output_More->Visible=false;
+    }
+    if (General_Output_Sel->ItemIndex==10)
+    {
+        Prefs->Config(__T("Output"))=__T("reVTMD");
+        MainF->Page->ActivePage=MainF->Page_Custom;
+        General_Output_More->Visible=false;
+    }
+    if (General_Output_Sel->ItemIndex==11)
     {
         Prefs->Config(__T("Output"))=__T("Custom");
         MainF->Page->ActivePage=MainF->Page_Custom;
@@ -502,8 +515,10 @@ void __fastcall TPreferencesF::GUI_Configure()
     General_Output_Sel->Items->Add(Prefs->Translate(__T("Text")).c_str());
     General_Output_Sel->Items->Add(Prefs->Translate(__T("HTML")).c_str());
     General_Output_Sel->Items->Add("XML");
+    General_Output_Sel->Items->Add("JSON");
     General_Output_Sel->Items->Add("MPEG-7");
     General_Output_Sel->Items->Add("PBCore_1.2");
+    General_Output_Sel->Items->Add("PBCore_2.0");
     General_Output_Sel->Items->Add("reVTMD");
     General_Output_Sel->Items->Add(Prefs->Translate(__T("Custom")).c_str());
          if (Prefs->Config(__T("Output"))==__T("Basic"))      General_Output_Sel->ItemIndex=0;
@@ -512,10 +527,12 @@ void __fastcall TPreferencesF::GUI_Configure()
     else if (Prefs->Config(__T("Output"))==__T("Text"))       General_Output_Sel->ItemIndex=3;
     else if (Prefs->Config(__T("Output"))==__T("HTML"))       General_Output_Sel->ItemIndex=4;
     else if (Prefs->Config(__T("Output"))==__T("XML"))        General_Output_Sel->ItemIndex=5;
-    else if (Prefs->Config(__T("Output"))==__T("MPEG-7"))     General_Output_Sel->ItemIndex=6;
-    else if (Prefs->Config(__T("Output"))==__T("PBCore_1.2")) General_Output_Sel->ItemIndex=7;
-    else if (Prefs->Config(__T("Output"))==__T("reVTMD"))     General_Output_Sel->ItemIndex=8;
-    else if (Prefs->Config(__T("Output"))==__T("Custom"))     General_Output_Sel->ItemIndex=9;
+    else if (Prefs->Config(__T("Output"))==__T("XML"))        General_Output_Sel->ItemIndex=6;
+    else if (Prefs->Config(__T("Output"))==__T("MPEG-7"))     General_Output_Sel->ItemIndex=7;
+    else if (Prefs->Config(__T("Output"))==__T("PBCore_1.2")) General_Output_Sel->ItemIndex=8;
+    else if (Prefs->Config(__T("Output"))==__T("PBCore_2.0")) General_Output_Sel->ItemIndex=9;
+    else if (Prefs->Config(__T("Output"))==__T("reVTMD"))     General_Output_Sel->ItemIndex=10;
+    else if (Prefs->Config(__T("Output"))==__T("Custom"))     General_Output_Sel->ItemIndex=11;
     //-Advanced
     Setup_Advanced->Caption=Prefs->Translate(__T("Advanced")).c_str();
     CB_InscrireShell->Caption=Prefs->Translate(__T("Shell extension")).c_str();
