@@ -40,6 +40,7 @@ enum
     ID_Menu_View_Text,
     ID_Menu_View_HTML,
     ID_Menu_View_XML,
+    ID_Menu_View_JSON,
     ID_Menu_View_MPEG7,
     ID_Menu_View_PBCore_1_2,
     ID_Menu_View_PBCore_2_0,
@@ -75,6 +76,7 @@ BEGIN_EVENT_TABLE(GUI_Main, wxFrame)
     EVT_MENU(ID_Menu_View_Text,             GUI_Main::OnMenu_View_Text)
     EVT_MENU(ID_Menu_View_HTML,             GUI_Main::OnMenu_View_HTML)
     EVT_MENU(ID_Menu_View_XML,              GUI_Main::OnMenu_View_XML)
+    EVT_MENU(ID_Menu_View_JSON,             GUI_Main::OnMenu_View_JSON)
     EVT_MENU(ID_Menu_View_MPEG7,            GUI_Main::OnMenu_View_MPEG7)
     EVT_MENU(ID_Menu_View_PBCore_1_2,       GUI_Main::OnMenu_View_PBCore_1_2)
     EVT_MENU(ID_Menu_View_PBCore_2_0,       GUI_Main::OnMenu_View_PBCore_2_0)
@@ -134,6 +136,7 @@ void GUI_Main::Menu_Create()
     Menu_View_Text              =Menu_View->AppendRadioItem(ID_Menu_View_Text, __T("Text"));
     Menu_View_HTML              =Menu_View->AppendRadioItem(ID_Menu_View_HTML, __T("HTML"));
     Menu_View_XML               =Menu_View->AppendRadioItem(ID_Menu_View_XML, __T("XML"));
+    Menu_View_JSON              =Menu_View->AppendRadioItem(ID_Menu_View_JSON, __T("JSON"));
     Menu_View_MPEG7             =Menu_View->AppendRadioItem(ID_Menu_View_MPEG7, __T("MPEG-7"));
     Menu_View_PBCore_1_2        =Menu_View->AppendRadioItem(ID_Menu_View_PBCore_1_2, __T("PBCore 1.2"));
     Menu_View_PBCore_2_0        =Menu_View->AppendRadioItem(ID_Menu_View_PBCore_2_0, __T("PBCore 2.0"));
@@ -294,6 +297,17 @@ void GUI_Main::OnMenu_View_XML(wxCommandEvent& WXUNUSED(event))
     delete View; View = View_New;
 }
 
+//---------------------------------------------------------------------------
+void GUI_Main::OnMenu_View_JSON(wxCommandEvent& WXUNUSED(event))
+{
+    //Configuring
+    C->Menu_View_JSON();
+
+    //Showing
+    GUI_Main_Common_Core* View_New = new GUI_Main_Text(C, this);
+    delete View; View = View_New;
+}
+
 //---------------------------------------------------------------------------
 void GUI_Main::OnMenu_View_MPEG7(wxCommandEvent& WXUNUSED(event))
 {
